@@ -77,7 +77,13 @@ hpaste <- function(..., sep = "", collapse = ", ", lastCollapse = NULL, maxHead
 
 stealth_sample.int <- function(n, size = n, replace = FALSE, ...) {
   oseed <- .GlobalEnv$.Random.seed
-  on.exit(.GlobalEnv$.Random.seed <- oseed)
+  on.exit({
+    if (is.null(oseed)) {
+      rm(list = ".Random.seed", envir = .GlobalEnv, inherits = FALSE)
+    } else {
+      .GlobalEnv$.Random.seed <- oseed
+    }
+  })
   sample.int(n = n, size = size, replace = replace, ...)
 }
 
